@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 import argparse
-from sarscov2metaextract import formatter
+from sarscov2formatter import formatter
 
 
 def main():
